Client

Struct Client 

pub struct Client { /* private fields */ }
HTTP client for making outbound requests.

Example

use wasm_runner_sdk::http::Client;

let client = Client::new();
let response = client.get("https://api.example.com/data").send()?;
let data: MyData = response.json()?;

Implementations

Source

impl Client

pub fn new() -> Self

Creates a new HTTP client.

pub fn with_default_headers(headers: Vec<(String, String)>) -> Self

Creates a client with default headers that will be sent with every request.

pub fn default_header( self, name: impl Into<String>, value: impl Into<String>, ) -> Self

Adds a default header that will be sent with every request.

pub fn get(&self, url: impl Into<String>) -> RequestBuilder

Creates a GET request.

pub fn post(&self, url: impl Into<String>) -> RequestBuilder

Creates a POST request.

pub fn put(&self, url: impl Into<String>) -> RequestBuilder

Creates a PUT request.

pub fn delete(&self, url: impl Into<String>) -> RequestBuilder

Creates a DELETE request.

pub fn patch(&self, url: impl Into<String>) -> RequestBuilder

Creates a PATCH request.

pub fn head(&self, url: impl Into<String>) -> RequestBuilder

Creates a HEAD request.

pub fn request( &self, method: impl Into<String>, url: impl Into<String>, ) -> RequestBuilder

Creates a request with the given method.