StatusCode

Struct StatusCode 

pub struct StatusCode(/* private fields */);
HTTP status code.

Implementations

Source

impl StatusCode

pub const OK: StatusCode

pub const CREATED: StatusCode

pub const ACCEPTED: StatusCode

pub const NO_CONTENT: StatusCode

pub const MOVED_PERMANENTLY: StatusCode

pub const FOUND: StatusCode

pub const SEE_OTHER: StatusCode

pub const NOT_MODIFIED: StatusCode

pub const TEMPORARY_REDIRECT: StatusCode

pub const PERMANENT_REDIRECT: StatusCode

pub const BAD_REQUEST: StatusCode

pub const UNAUTHORIZED: StatusCode

pub const FORBIDDEN: StatusCode

pub const NOT_FOUND: StatusCode

pub const METHOD_NOT_ALLOWED: StatusCode

pub const CONFLICT: StatusCode

pub const GONE: StatusCode

pub const UNPROCESSABLE_ENTITY: StatusCode

pub const TOO_MANY_REQUESTS: StatusCode

pub const INTERNAL_SERVER_ERROR: StatusCode

pub const NOT_IMPLEMENTED: StatusCode

pub const BAD_GATEWAY: StatusCode

pub const SERVICE_UNAVAILABLE: StatusCode

pub const GATEWAY_TIMEOUT: StatusCode

pub const fn from_u16(code: u16) -> Self

Creates a status code from a raw u16 value.

pub const fn as_u16(&self) -> u16

Returns the raw status code value.

pub const fn is_success(&self) -> bool

Returns true if this is a success status (2xx).

pub const fn is_redirection(&self) -> bool

Returns true if this is a redirection status (3xx).

pub const fn is_client_error(&self) -> bool

Returns true if this is a client error status (4xx).

pub const fn is_server_error(&self) -> bool

Returns true if this is a server error status (5xx).